@@ -65,12 +65,9 @@ read_pfile <- function(fname, n_ref_scans = NULL) {
   ref <- def_ref()
   nuc <- def_nuc()
   
-  mrs_data <- list(ft = hdr$ps_mps_freq / 10, data = data, resolution = res,
-                   te = hdr$te, ref = ref, nuc = nuc, row_vec = NA,
-                   col_vec = NA, pos_vec = NA, sli_vec = NA,
-                   freq_domain = freq_domain)
-  
-  class(mrs_data) <- "mrs_data"
+  mrs_data <- mrs_data(data = data, ft = hdr$ps_mps_freq / 10, resolution = res,
+                       te = hdr$te, ref = ref, nuc = nuc,
+                       freq_domain = freq_domain, affine = NULL, meta = NULL)
   
   if (hdr$rhuser19 > 0) {
     # split water and metab data for each echo
