@@ -118,13 +118,11 @@ read_spar_sdat <- function(fname) {
   # freq domain vector
   freq_domain <- rep(FALSE, 7)
   
-  mrs_data <- list(ft = ft, data = data, resolution = res, te = te, ref = ref, 
-                   nuc = nuc, row_vec = row_ori, col_vec = col_ori,
-                   sli_vec = sli_vec, pos_vec = pos_vec,
-                   freq_domain = freq_domain)
+  mrs_data <- mrs_data(data = data, ft = ft, resolution = res, te = te,
+                       ref = ref, nuc = nuc, freq_domain = freq_domain,
+                       affine = NULL, meta = NULL)
   
-  class(mrs_data) <- "mrs_data"
-  mrs_data
+  return(mrs_data)
 }
 
 # this is slow and not used, but kept as a reference
